@@ -2,7 +2,7 @@ import os
 import glob
 import collections.abc
 import sys
-
+sys.path.append(os.getcwd())
 
 class ConfigEnv:
     def __init__(self) -> None:
@@ -38,17 +38,6 @@ class ConfigEnv:
            
     def __get_path_files(self):
         result = []
-        # It could be a problem once it can get configenv path from differents projects.
-        # for root, dirs, files in os.walk(os.getcwd(), topdown=False):
-        #     for dir in dirs:
-        #         if dir == "configenv":
-        #             os.chdir(os.path.join(root, dir))
-        #             for file in glob.glob("*.json"):
-        #                 result.append(os.path.join(root, dir, file))
-        #             if len(result) > 0:
-        #                 break
-        #     if len(result) > 0:
-        #         break
 
         if not result:
             for path in sys.path:
